%VECTOR EXAMPLE (Object falling):

x0 = 0.1;
v0 = 0.1;
TMAX = 100;

g=9.8;
m=1.0;
k=10.0;
dt=0.01;

% Define the system as a constant of 12 volts:
clear s
s.A = [[1      dt          0]; ... 
       [0 (1.0-(k/m)*dt) -g*dt]; ...
       [0       0          1]];
% Define process noise
s.Q = eye(3)*0.01; 

% Define measurement function to return the state
s.H = eye(3);

% Define a measurement error
s.R = eye(3)*0.01;% 2^2; % variance, hence stdev^2

% Do not define any system input (control) functions:
s.B = eye(3); % Control matrix
s.u = [0 0 0]'; % No command
% Initial state:
%s.x = nan;
%s.P = nan;
s.x = [x0 v0 1.0]';
s.P = eye(3)*.01;
s.z = zeros(3,1);
% Generate random voltages and watch the filter operate.
tru=zeros(TMAX,3); % true dynamics
tru(1,:)=[x0 v0 1.0];
for t=2:TMAX
   tru(t,:) = s(t-1).A * tru(t-1,:)';
   s(t-1).z = s(t-1).H * tru(t,:)' + 0.02*randn*[1 1 0]'; % create a measurement
   s(t)=kalmanf(s(t-1)); % perform a Kalman filter iteration
end

xout = zeros(TMAX,3);
zout = zeros(TMAX,3);
for t=1:100
    xout(t,:) = s(t).x
    zout(t,:) = s(t).z
end


figure(1)
subplot(2,1,1);
hold on
grid on
% plot measurement of position
hzvel=plot(zout(:,1),'r.');
% plot a-posteriori state estimates:
hxvel=plot(xout(:,1),'b-');
htvel=plot(tru(:,1),'g-');
legend([hzvel hxvel htvel],'observations','Kalman output','true dynamics',0)
title('Position of object falling in air ')
hold off

subplot(2,1,2)
hold on
grid on
% plot measurement of position
hzvel=plot(zout(:,2),'r.');
% plot a-posteriori state estimates:
hxvel=plot(xout(:,2),'b-');
htvel=plot(tru(:,2),'g-');
legend([hzvel hxvel htvel],'observations','Kalman output','true dynamics',0)
title('Velocity of object falling in air ')
hold off
